PixelFluxStatus class

Represents the current status of the PixelFlux player

Constructors

PixelFluxStatus({bool playing = false, int frameIndex = 0, double speed = 1.0, LoopMode loopMode = LoopMode.loop, bool reverse = false})
Creates a PixelFluxStatus with the given parameters
const

Properties

frameIndex int
The current frame index being displayed
final
hashCode int
The hash code for this object.
no setterinherited
loopMode LoopMode
The looping behavior for video playback
final
playing bool
Whether the video is currently playing
final
reverse bool
Whether the video is playing in reverse
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
speed double
Playback speed multiplier (1.0 = normal speed)
final

Methods

copyWith({bool? playing, int? frameIndex, double? speed, LoopMode? loopMode, bool? reverse}) PixelFluxStatus
Creates a copy of this status with the given fields replaced
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited